xweights.Input
==============

.. currentmodule:: xweights

.. autoclass:: Input

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Input.__init__
      ~Input.create_dataset_dict
      ~Input.create_input_dictionary
      ~Input.identify_input_format
      ~Input.open_intake_esm_catalogue
      ~Input.open_xrdataset
   
   

   
   
   